// Gmsh project created on Sun Nov 06 17:11:29 2022
SetFactory("OpenCASCADE");

// dimensions in millimeters
// convert to meters using elmergrid: "-scale 0.001 0.001 0.001"

// rectangular box, 250 by 500 by 200
// Two large flat cylinders, 100 radius by 1.0 height

/// mesh size at eight corners of the enclosure
bx = 20.0;
// mesh both membranes finer than the enclosure
Mesh.MeshSizeFromCurvature = 72;

Mesh.OptimizeNetgen = 1;

//+
Point(1) = {0, 0, 0, bx};
//+
Point(2) = {250, 0, 0, bx};
//+
Point(3) = {250, 500, 0, bx};
//+
Point(4) = {0, 500, 0, bx};
//+
Point(5) = {0, 0, 200, bx};
//+
Point(6) = {250, 0, 200, bx};
//+
Point(7) = {250, 500, 200, bx};
//+
Point(8) = {0, 500, 200, bx};
//+
Line(1) = {1, 2};
//+
Line(2) = {2, 3};
//+
Line(3) = {3, 4};
//+
Line(4) = {4, 1};
//+
Line(5) = {5, 6};
//+
Line(6) = {6, 7};
//+
Line(7) = {7, 8};
//+
Line(8) = {8, 5};
//+
Line(9) = {1, 5};
//+
Line(10) = {2, 6};
//+
Line(11) = {4, 8};
//+
Line(12) = {3, 7};
//+
Curve Loop(1) = {1, 2, 3, 4};
//+
Plane Surface(1) = {1};
//+
Curve Loop(2) = {9, -8, -11, 4};
//+
Plane Surface(2) = {2};
//+
Curve Loop(3) = {9, 5, -10, -1};
//+
Plane Surface(3) = {3};
//+
Curve Loop(4) = {10, 6, -12, -2};
//+
Plane Surface(4) = {4};
//+
Curve Loop(5) = {8, 5, 6, 7};
//+
Plane Surface(5) = {5};
//+
Curve Loop(6) = {11, -7, -12, 3};
//+
Plane Surface(6) = {6};
//+
Surface Loop(1) = {5, 2, 3, 4, 6, 1};

//+
Volume(1) = {1};
//+
Cylinder(2) = {125, 125, 0,   0, 0, 1.0,  100, 2*Pi};
//+
Cylinder(3) = {125, 375, 0,   0, 0, 1.0,  100, 2*Pi};
//+ creates volume 4
BooleanFragments{ Volume{1}; Delete; }{ Volume{2}; Volume{3}; Delete; }

//+
Physical Surface("enclosure_walls", 31) = {14, 13, 17, 15, 18, 16};

//+
Physical Surface("membrane_surface_upper", 32) = {12};
//+
Physical Surface("membrane_rim_upper", 33) = {10};
//+
Physical Surface("fsi_interface_upper", 34) = {11};
//+
Physical Surface("membrane_surface_lower", 35) = {9};
//+
Physical Surface("membrane_rim_lower", 36) = {7};
//+
Physical Surface("fsi_interface_lower", 37) = {8};

//+
Physical Volume("fluid_body", 38) = {4};
//+
Physical Volume("membrane_body_upper", 39) = {3};
//+
Physical Volume("membrane_body_lower", 40) = {2};
